require 'sqlite3'

module Rise
  module MirrorManager
    # Module for database interaction
    module Database
      DB = SQLite3::Database.open(Rise::MirrorManager.configuration.database, results_as_hash: true)

      def get_sync_status(mirror_name)
        columns = %w[sync_status total_bandwidth error]
        row = DB.execute("SELECT #{columns.join(',')} FROM sync_info WHERE mirror_id = (SELECT mirror_id FROM mirrors WHERE name = ?)", [mirror_name])[0] #Retrieve first row of the Array
        if row.nil? || row.empty?
          nil
        else
          return row.select { |key, _| columns.include?(key.to_s) }
        end
      end

      def update_sync_status(mirror_name:, status:, total_bandwidth: nil, error: nil)
        mirror_id = retrieve_mirror_id(mirror_name)
        if sync_info_exists?(mirror_id)
          DB.execute 'UPDATE sync_info SET sync_status =  ?, total_bandwidth = ?, error = ? WHERE mirror_id = ?', [status, total_bandwidth, error, mirror_id]
        else
          DB.execute 'INSERT INTO sync_info (mirror_id, sync_status, total_bandwidth, error) VALUES (?, ?, ?, ?)', [mirror_id, status, total_bandwidth, error]
        end
      end

      private

      def retrieve_mirror_id(mirror_name)
        row = (DB.execute 'SELECT mirror_id FROM mirrors WHERE name = ?', [mirror_name])[0]
        if row.nil? || row.empty?
          raise "#{mirror_name} not in database."
        else
          row["mirror_id"]
        end
      end

      def sync_info_exists?(mirror_id)
        sync_info = DB.execute 'SELECT sync_info_id FROM sync_info WHERE mirror_id = ?', [mirror_id]
        if sync_info.nil? || sync_info.empty?
          false
        else
          true
        end
      end
    end
  end
end
