require_relative 'configuration'
require 'logger'

module Rise
  module MirrorManager
    # Module containing logging functionalities
    module Logging
      class << self
        attr_reader :app_logger
      end

      def self.setup_logger
        log_file = File.new(File.join(Rise::MirrorManager.configuration.log_dir, 'mirror_manager.log'), File::CREAT | File::WRONLY | File::APPEND)
        log_file.sync = true
        app_logger = Logger.new(log_file, 'weekly',
                                 formatter: proc { |severity, datetime, _progname, msg|
          "[#{Process.pid}][#{datetime}] #{severity} -- #{msg}\n"
        })
      end

      # class IOToLog < IO
      #   def initialize(logger)
      #     @logger = logger
      #   end

      #   def write(message)
      #     @logger.error message
      #   end
      # end

      # Logger object for individual sync jobs
      class SyncLog
        def initialize(filename)
          log_file = File.open(File.join(Rise::MirrorManager.configuration.log_dir,
                                         "#{filename}.log"), File::CREAT | File::WRONLY | File::APPEND)
          log_file.sync = true # flush logs in realtime
          @logger = Logger.new(log_file, 'weekly', formatter: proc { |severity, datetime, _progname, msg|
            "[#{Process.pid}:#{Thread.current.object_id}][#{datetime}] #{severity} -- #{msg}\n"
          })
        end

        def log_info(msg)
          logger.info msg
        end

        def log_warn(msg)
          logger.warn msg
        end

        def log_error(msg)
          logger.error msg
        end

        private

        attr_reader :logger
      end
    end
  end
end
