require_relative 'configuration'
require_relative 'logging'
require 'ostruct'
require 'inifile'

module Rise
  module MirrorManager
    # Module for Mirror data
    module Mirror
      def self.retrieve_mirrors(interval)
        mirrors = extract_mirrors(Rise::MirrorManager.configuration.mirror_data_file, interval)
        if mirrors.empty?
          raise "No mirror was retrieved for interval: #{interval}."
        end
        mirrors
      end

      def self.extract_mirrors(mirror_data_file, interval)
        data_file = IniFile.load(mirror_data_file)
        if data_file.nil?
          raise "#{mirror_data_file} not found."
        end
        mirrors = []
        data_file.each_section do |section|
          next if data_file[section]['INTERVAL'] != interval
          mirror = OpenStruct.new(name: data_file[section]['NAME'])
          if data_file[section]['CUSTOM_SCRIPT']
            mirror[:custom_script] = data_file[section]['CUSTOM_SCRIPT']
          else
            mirror[:remote_source] = data_file[section]['REMOTE_SOURCE']
            mirror[:local_dir] = data_file[section]['LOCAL_DIR']
            mirror[:rsync_opts] = data_file[section]['RSYNC_OPTS']
            mirror[:rsync_del_opts] = data_file[section]['RSYNC_DEL_OPTS']
            mirror[:exclude] = data_file[section]['EXCLUDE']
            mirror[:include] = data_file[section]['INCLUDE']
            mirror[:filter] = data_file[section]['FILTER']
            mirror[:precmd] = data_file[section]['PRECMD']
            mirror[:postcmd] = data_file[section]['POSTCMD']
            mirror[:depth] = data_file[section]['DEPTH']
          end
          mirrors << mirror
        end
        mirrors
      end end
  end
end
